import { Injectable } from "@angular/core";
import { Platform } from "ionic-angular";
import { PouchService } from "@justbe-angular/jb-pouch";
import { AppPreferences } from "@ionic-native/app-preferences";
import { Observable } from "rxjs";
import { HttpService } from "@justbe-angular/jb-http";
import { StoreService } from "@justbe-angular/jb-store";
var AuthDataHandlerService = (function () {
    function AuthDataHandlerService(plt, pouchService, appPreferences, httpService, storeService) {
        this.plt = plt;
        this.pouchService = pouchService;
        this.appPreferences = appPreferences;
        this.httpService = httpService;
        this.storeService = storeService;
    }
    ;
    AuthDataHandlerService.prototype.saveAuthData = function (auth) {
        auth["id"] = 'jb-auth';
        if (this.plt.is('core') || this.plt.is('mobileweb')) {
            this.pouchService.upsertDocument('justbe-application', auth).subscribe(function (res) { }, function (err) { });
            this.storeService.updateSubstore('jb-auth', auth);
        }
        else {
            var strAuth = JSON.stringify(auth);
            this.appPreferences.store('jb-auth', strAuth);
            this.storeService.updateSubstore('jb-auth', auth);
        }
    };
    AuthDataHandlerService.prototype.clearData = function () {
        var _this = this;
        return new Observable(function (observer) {
            _this.httpService.deleteHeaders();
            _this.pouchService.deleteAllDatabases().subscribe(function (res) {
                _this.appPreferences.clearAll();
                _this.storeService.deleteSubStore('jb-auth');
                observer.next(200);
                observer.complete();
            }, function (err) {
                observer.error(500);
            });
        });
    };
    AuthDataHandlerService.prototype.getAuthData = function () {
        var obs;
        if (this.plt.is('core') || this.plt.is('mobileweb')) {
            obs = this.handleBrowser();
        }
        else {
            obs = this.handleNative();
        }
        return obs;
    };
    AuthDataHandlerService.prototype.handleBrowser = function () {
        var _this = this;
        return new Observable(function (observer) {
            _this.pouchService.getDocument('justbe-application', 'jb-auth').subscribe(function (auth) {
                observer.next(auth);
                observer.complete();
            }, function (err) {
                if (err.status === 404) {
                    observer.error('no auth data found');
                }
            });
        });
    };
    AuthDataHandlerService.prototype.handleNative = function () {
        var _this = this;
        return new Observable(function (observer) {
            _this.appPreferences.fetch('jb-auth').then(function (auth) {
                if (auth.length > 0) {
                    auth = JSON.parse(auth);
                    observer.next(auth);
                    observer.complete();
                }
                else {
                    observer.error('no auth data found');
                }
            }).catch(function (err) {
                observer.error('try after some time');
            });
        });
    };
    AuthDataHandlerService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AuthDataHandlerService.ctorParameters = function () { return [
        { type: Platform, },
        { type: PouchService, },
        { type: AppPreferences, },
        { type: HttpService, },
        { type: StoreService, },
    ]; };
    return AuthDataHandlerService;
}());
export { AuthDataHandlerService };
//# sourceMappingURL=auth-data-handler.service.js.map