import { Injectable } from "@angular/core";
import { Observable } from "rxjs";
import { JbAuthModel } from "../models/jb-auth.model";
import { HttpService } from "@justbe-angular/jb-http";
import { AuthDataHandlerService } from "./auth-data-handler.service";
import { AutherService } from "@justbe-angular/jb-auther";
import { AfterLoginHandlerService } from "./after-login-handler.service";
var TokenGenHandleService = (function () {
    function TokenGenHandleService(httpService, autherService, authDataHandler, afterLoginHandle) {
        this.httpService = httpService;
        this.autherService = autherService;
        this.authDataHandler = authDataHandler;
        this.afterLoginHandle = afterLoginHandle;
    }
    ;
    TokenGenHandleService.prototype.genNHandle = function (gnhInputParamsModel) {
        var _this = this;
        return new Observable(function (observer) {
            _this.autherService.generateJustbeToken({
                token: {
                    profileType: gnhInputParamsModel.profileType,
                    profileVO: gnhInputParamsModel.oneLouveProfile
                },
                userId: gnhInputParamsModel.userId,
                api: gnhInputParamsModel.api
            }).subscribe(function (jbgenToken) {
                if (jbgenToken.accessToken) {
                    _this.handle({
                        authType: gnhInputParamsModel.profileType,
                        jbgenToken: jbgenToken,
                        api: gnhInputParamsModel.api,
                        profile: gnhInputParamsModel.oneLouveProfile
                    }).subscribe(function (res) {
                        observer.next(res);
                        observer.complete();
                    }, function (err) {
                        observer.error({ key: 2, msg: 'auth failed', desc: 'generate justbe token failed' });
                    });
                }
                else {
                    observer.error(500);
                }
            });
        });
    };
    TokenGenHandleService.prototype.handle = function (hInputParams) {
        var _this = this;
        return new Observable(function (observer) {
            _this.httpService.setHeaders("authorization", hInputParams.jbgenToken.accessToken);
            if (!hInputParams.profile) {
                _this.getProfile(hInputParams.api).subscribe(function (profile) {
                    _this.continueHandle(hInputParams.authType, hInputParams.jbgenToken, profile);
                    observer.next(200);
                    observer.complete();
                }, function (err) {
                    observer.error(err);
                });
            }
            else {
                _this.continueHandle(hInputParams.authType, hInputParams.jbgenToken, hInputParams.profile);
                observer.next(200);
                observer.complete();
            }
        });
    };
    TokenGenHandleService.prototype.continueHandle = function (authType, jbgenToken, profile) {
        profile.id = jbgenToken.systemProfileId;
        var auth = JbAuthModel.build({ authType: authType, generatedToken: jbgenToken, profile: profile });
        this.authDataHandler.saveAuthData(auth);
        this.afterLoginHandle.handle();
    };
    TokenGenHandleService.prototype.getProfile = function (api) {
        var _this = this;
        return new Observable(function (observer) {
            _this.autherService.getLiu({
                api: api
            }).subscribe(function (res) {
                if (res.id) {
                    observer.next(res);
                    observer.error();
                }
                else {
                    observer.error({ key: 1, msg: 'auth failed', desc: 'Unable to get profile from server' });
                }
            });
        });
    };
    TokenGenHandleService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    TokenGenHandleService.ctorParameters = function () { return [
        { type: HttpService, },
        { type: AutherService, },
        { type: AuthDataHandlerService, },
        { type: AfterLoginHandlerService, },
    ]; };
    return TokenGenHandleService;
}());
export { TokenGenHandleService };
//# sourceMappingURL=token-gen-handle.service.js.map